@@ -86,6 +86,7 @@ class H2OGLM(H2OGLMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
                  maxConfusionMatrixSize=20,
                  computePValues=False,
                  removeCollinearCols=False,
+                 generateScoringHistory=False,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -98,6 +99,7 @@ class H2OGLM(H2OGLMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
                  foldAssignment="AUTO",
                  ignoreConstCols=True,
                  scoreEachIteration=False,
+                 checkpoint=None,
                  stoppingRounds=0,
                  maxRuntimeSecs=0.0,
                  stoppingMetric="AUTO",
@@ -111,6 +113,7 @@ class H2OGLM(H2OGLMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGLM", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
         if 'distribution' in kwargs:
             del kwargs['distribution']
             warn("The parameter 'distribution' is deprecated and will be removed in the version 3.34.")
